@@ -36,6 +36,9 @@ class MoveLine(metaclass=PoolMeta):
             depends=['payment_kind', 'second_currency_digits',
                 'currency_digits']), 'get_payment_amount',
         searcher='search_payment_amount')
+    payment_currency = fields.Function(fields.Many2One(
+            'currency.currency', "Payment Currency"),
+        'get_payment_currency')
     payments = fields.One2Many('account.payment', 'line', 'Payments',
         readonly=True,
         states={
@@ -132,6 +135,12 @@ class MoveLine(metaclass=PoolMeta):
                 ))
         return [('id', 'in', query)]
 
+    def get_payment_currency(self, name):
+        if self.second_currency:
+            return self.second_currency.id
+        elif self.currency:
+            return self.currency.id
+
     def get_payment_kind(self, name):
         if (self.account.type.receivable
                 and (self.debit > 0 or self.credit < 0)):
@@ -234,7 +243,7 @@ class PayLine(Wizard):
                 'lines': list(),
                 }
             for kind in reverse.keys()}
-        lines = Line.browse(Transaction().context['active_ids'])
+        lines = self.records
         for line in lines:
             for kind in types:
                 if getattr(line.account.type, kind):
@@ -291,10 +300,7 @@ class PayLine(Wizard):
             return (company, currency)
 
     def _missing_journal(self):
-        pool = Pool()
-        Line = pool.get('account.move.line')
-
-        lines = Line.browse(Transaction().context['active_ids'])
+        lines = self.records
         journals = self._get_journals()
 
         for line in lines:
@@ -350,11 +356,10 @@ class PayLine(Wizard):
 
     def do_pay(self, action):
         pool = Pool()
-        Line = pool.get('account.move.line')
         Payment = pool.get('account.payment')
         Warning = pool.get('res.user.warning')
 
-        lines = Line.browse(Transaction().context['active_ids'])
+        lines = self.records
         journals = self._get_journals()
 
         payments = []
